==> 2025-12-30-17-10-28-MaaEOV-MaaEOV-win-x86_64-v1.0.3.zip: README.md <==
<!-- markdownlint-disable MD033 MD041 -->
<div align="center">

<img alt="LOGO" src="https://github.com/user-attachments/assets/00326df5-dd8c-4c63-94ef-f1716555431a" width="256" height="256" />

# MaaEOV

基于 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 的 [异象回声](https://eov.astral-vector.com/) 小助手。
旨在自动化完成日常任务，避免错过/忘记/懒得做日常。图像技术 + 模拟控制，解放双手！
<a href="https://github.com/Tigerisu/MaaEOV" target="_blank" style="font-weight: bold;">🔗 本项目 GitHub 仓库</a><br>
🌟喜欢本项目就在仓库右上角点个星星吧🌟

</div>

<p align="center">
  <img alt="Python" src="https://img.shields.io/badge/Python-3776AB?logo=python&logoColor=white">
  <img alt="platform" src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux%20%7C%20macOS-blueviolet">
  <img alt="license" src="https://img.shields.io/github/license/Tigerisu/MaaEOV">
  <br>
  <img alt="commit" src="https://img.shields.io/github/commit-activity/m/Tigerisu/MaaEOV">
  <img alt="stars" src="https://img.shields.io/github/stars/Tigerisu/MaaEOV?style=social">
  <img alt="downloads" src="https://img.shields.io/github/downloads/Tigerisu/MaaEOV/total?style=social">
  <!-- <a href="https://mirrorchyan.com/zh/projects?rid=M9A&source=m9agh-badge" target="_blank"><img alt="mirrorc" src="https://img.shields.io/badge/Mirror%E9%85%B1-%239af3f6?logo=countingworkspro&logoColor=4f46e5"></a> -->
</p>

<div align="center">

<!-- [English](./README_en.md) | [简体中文](./README.md) -->

</div>

## 公告

>[!IMPORTANT]
>
>请注意：
>
>- 当前版本似乎已经可以稳定运行。建议使用时在监督下运行一次，以确认功能运行正常。如在使用过程中遇到问题，欢迎通过 Issues 反馈。
>- 由于《异象回声》桌面互通版需要跳转浏览器登录，**MaaEOV暂无对桌面互通版的支持计划**，请搭配模拟器使用。

---

>[!TIP]
>
>新版本 **[MFAAvalonia](https://github.com/SweetSmellFox/MFAAvalonia)** 近期已趋于稳定，项目后续可能会升级至较新版本。若升级 GUI，用户可能需要安装 .NET 10，并对 配置文件 进行调整，具体说明将另行发布。
>
>**建议对保存的配置文件（`MaaEOV/config/<配置名称>.json`）进行备份以免丢失。**

## 使用说明

- [新手上路](./docs/zh_cn/manual/新手上路.md)(**使用前必看**)
- [功能介绍](./docs/zh_cn/manual/功能介绍.md)
- [MaaPiCli使用说明](./docs/zh_cn/manual/MaaPiCli.md)
- [连接设置](./docs/zh_cn/manual/连接设置.md)
<!-- - [常见问题](./docs/zh_cn/manual/常见问题.md) -->
<!-- - [Mirror酱使用说明](./docs/zh_cn/manual/Mirror酱.md) -->

>[!WARNING]
>
>在游戏的 **设置 → 画面** 中，请确保 **「低分辨率」选项处于关闭状态**。开启该选项会导致功能异常。
>
><img alt="game_settings" src="https://github.com/user-attachments/assets/c7d95899-8c17-48c9-a6d7-c53f9da871fb" />

## 功能列表

- 启动游戏
- 每周-阈限禁区
- 清体力
- 危机行动调令
- 事务所（解读仪式）
- 市区巡逻
- 领取任务奖励
- 领取应对协议
- 领取邮件
- 补给站
- 外部招募
- 退出游戏
- 活动-每日行动补给
- 联线封锁
- 活动-短期支援补贴

>[!NOTE]
>认知海域 的自动扫荡功能在更新计划中。
>鉴于官方直播中似乎提到过此玩法的优化计划，且该功能的实现较为复杂，故将其开发计划推迟到进一步稳定现有功能之后。

## 开发相关

更多文档请前往 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 主仓库查看

## 鸣谢

- 本项目由 **[MaaFramework](https://github.com/MaaXYZ/MaaFramework)** 强力驱动！
- 项目模板：[MaaPracticeBoilerplate](https://github.com/MaaXYZ/MaaPracticeBoilerplate)
- GUI: [MFAAvalonia](https://github.com/SweetSmellFox/MFAAvalonia)
- Debugger: [MaaDebugger](https://github.com/MaaXYZ/MaaDebugger)
- Tool: [MFATools](https://github.com/SweetSmellFox/MFATools)
- 参考：[M9A](https://github.com/MAA1999/M9A)

<!-- 感谢以下开发者对本项目作出的贡献:

[![Contributors](https://contrib.rocks/image?repo=Tigerisu/MaaEOV&max=1000)](https://github.com/Tigerisu/MaaEOV/graphs/contributors) -->

==> 2026-02-12-22-23-55-MaaEOV-MaaEOV-win-x86_64-v1.0.8.zip: README.md <==
<!-- markdownlint-disable MD033 MD041 -->
<div align="center">

<img alt="LOGO" src="https://github.com/user-attachments/assets/00326df5-dd8c-4c63-94ef-f1716555431a" width="256" height="256" />

# MaaEOV

基于 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 的 [异象回声](https://eov.astral-vector.com/) 小助手。  
旨在自动化完成日常任务，避免错过/忘记/懒得做日常。图像技术 + 模拟控制，解放双手！  
<a href="https://github.com/Tigerisu/MaaEOV" target="_blank" style="font-weight: bold;">🔗 本项目 GitHub 仓库</a><br>  
🌟喜欢本项目就在仓库右上角点个星星吧🌟

</div>

<p align="center">
  <img alt="Python" src="https://img.shields.io/badge/Python-3776AB?logo=python&logoColor=white">
  <img alt="platform" src="https://img.shields.io/badge/platform-Windows%20%7C%20Linux%20%7C%20macOS-blueviolet">
  <img alt="license" src="https://img.shields.io/github/license/Tigerisu/MaaEOV">
  <br>
  <img alt="commit" src="https://img.shields.io/github/commit-activity/m/Tigerisu/MaaEOV">
  <img alt="stars" src="https://img.shields.io/github/stars/Tigerisu/MaaEOV?style=social">
  <img alt="downloads" src="https://img.shields.io/github/downloads/Tigerisu/MaaEOV/total?style=social">
  <!-- <a href="https://mirrorchyan.com/zh/projects?rid=M9A&source=m9agh-badge" target="_blank"><img alt="mirrorc" src="https://img.shields.io/badge/Mirror%E9%85%B1-%239af3f6?logo=countingworkspro&logoColor=4f46e5"></a> -->
</p>

<div align="center">

<!-- [English](./README_en.md) | [简体中文](./README.md) -->

</div>

## 公告

>[!IMPORTANT]
>
>请注意：
>
>- 当前版本似乎已经可以稳定运行。建议使用时在监督下运行一次，以确认功能运行正常。如在使用过程中遇到问题，欢迎通过 Issues 反馈。
>- 由于《异象回声》桌面互通版需要跳转浏览器登录，**MaaEOV暂无对桌面互通版的支持计划**，请搭配模拟器使用。
<!-- 
---

>[!TIP]
>
>新版本 **[MFAAvalonia](https://github.com/SweetSmellFox/MFAAvalonia)** 近期已趋于稳定，项目后续可能会升级至较新版本。若升级 GUI，用户可能需要安装 .NET 10，并对 配置文件 进行调整，具体说明将另行发布。
>
>**建议对保存的配置文件（`MaaEOV/config/<配置名称>.json`）进行备份以免丢失。** -->

## 使用说明

- [新手上路](./docs/zh_cn/manual/新手上路.md)(**使用前必看**)
- [功能介绍](./docs/zh_cn/manual/功能介绍.md)
- [MaaPiCli使用说明](./docs/zh_cn/manual/MaaPiCli.md)
- [连接设置](./docs/zh_cn/manual/连接设置.md)
<!-- - [常见问题](./docs/zh_cn/manual/常见问题.md) -->
<!-- - [Mirror酱使用说明](./docs/zh_cn/manual/Mirror酱.md) -->

>[!WARNING]
>
>在游戏的 **设置 → 画面** 中，请确保 **「低分辨率」选项处于关闭状态**。开启该选项会导致功能异常。
>
><img alt="game_settings" src="https://github.com/user-attachments/assets/c7d95899-8c17-48c9-a6d7-c53f9da871fb" />

## 功能列表

- 启动游戏
- 每周-阈限禁区
- 清体力
- 危机行动调令
- 事务所（解读仪式）
- 市区巡逻
- 领取任务奖励
- 领取应对协议
- 领取邮件
- 补给站
- 外部招募
- 退出游戏
- 活动-每日行动补给
- 联线封锁
- 活动-短期支援补贴

>[!NOTE]
>认知海域 的自动扫荡功能在更新计划中。
>鉴于官方直播中似乎提到过此玩法的优化计划，且该功能的实现较为复杂，故将其开发计划推迟到进一步稳定现有功能之后。

## 开发相关

更多文档请前往 [MaaFramework](https://github.com/MaaXYZ/MaaFramework) 主仓库查看

## 鸣谢

- 本项目由 **[MaaFramework](https://github.com/MaaXYZ/MaaFramework)** 强力驱动！
- 项目模板：[MaaPracticeBoilerplate](https://github.com/MaaXYZ/MaaPracticeBoilerplate)
- GUI: [MFAAvalonia](https://github.com/SweetSmellFox/MFAAvalonia)
- Debugger: [MaaDebugger](https://github.com/MaaXYZ/MaaDebugger)
- Tool: [MFATools](https://github.com/SweetSmellFox/MFATools)
- 参考：[M9A](https://github.com/MAA1999/M9A)

<!-- 感谢以下开发者对本项目作出的贡献:

[![Contributors](https://contrib.rocks/image?repo=Tigerisu/MaaEOV&max=1000)](https://github.com/Tigerisu/MaaEOV/graphs/contributors) -->
